pub struct NodeId(_);
A node ID stored as u32.

An index into a Tree-internal Vec.

Note that this value should be used with care since roxmltree doesn’t check that NodeId actually belongs to a selected Document. So you can end up in a situation, when NodeId produced by one Document is used to select a node in another Document.

Implementations

Construct a new NodeId from a u32.

u32 is more than enough since we have a 4GiB input data limit anyway.

Returns the u32 representation of the NodeId.

Returns the usize representation of the NodeId.