Struct roxmltree::ParsingOptions
source · [−]pub struct ParsingOptions {
pub allow_dtd: bool,
}Expand description
Parsing options.
Fields
allow_dtd: boolAllow DTD parsing.
When set to false, XML with DTD will cause an error.
Empty DTD block is not an error.
Currently, there is no option to simply skip DTD.
Mainly because you will get UnknownEntityReference error later anyway.
This flag is set to false by default for security reasons,
but roxmltree still has checks for billion laughs attack,
so this is just an extra security measure.
Default: false